// Hello, World! application. Copyright (C) 1996-1998 Santa Fe Institute.
// This library is distributed without any warranty; without even the
// implied warranty of merchantability or fitness for a particular purpose.
// See file LICENSE for details and terms of copying.

#import <objectbase/Swarm.h>
#import "Counter.h"
#import "Person.h"

@interface PplModelSwarm: Swarm
{
  // MODIFY: add your own simulation parameters
  int increment;

  // these are variables specific to the modelswarm that
  //  carry info about the overall model
  int numPpl;
  int numberPplStillTalking;

  // declare a list in which party-goers will reside
  id pplList;

  id modelActions;
  id modelSchedule;

  // MODIFY: add your own model objects.  
  Counter *counter;
}

// MODIFY: add access methods for what agents are visible.
-(Counter *)getCounter;

+createBegin: (id) aZone;
-createEnd;
-buildObjects;
-buildActions;
-activateIn: (id) swarmContext;

// message from people saying their done talking
-ImFinished;
// method for passing how many are talking back to observer
- (int) getNumberPplStillTalking;

@end
